#! /usr/bin/env bash

cd $HOME

apt update \
    && apt install -y \
    g++ cmake flex bison git python3 r-base \
    texlive-latex-base texlive-latex-extra

if [ $? -ne 0 ]; then
    echo "Failed Installing APT Dependencies!"
    exit 1
fi

GTEST_GIT="https://github.com/google/googletest"
GTEST_GIT_BRANCH="release-1.8.0"
GTEST_HOME="$HOME/googletest"

JSONCPP_GIT="https://github.com/open-source-parsers/jsoncpp"
JSONCPP_GIT_BRANCH="1.8.4"
JSONCPP_HOME="$HOME/jsoncpp"

EFD_GIT="https://github.com/ysiraichi/enfield"
EFD_HOME="$HOME/enfield"
EFD_EXE="$EFD_BUILD_HOME/tools/efd"

[ ! -d $GTEST_HOME ] && git clone $GTEST_GIT $GTEST_HOME
[ ! -d $JSONCPP_HOME ] && git clone $JSONCPP_GIT $JSONCPP_HOME
[ ! -d $EFD_HOME ] && git clone $EFD_GIT $EFD_HOME

rm -rf "$GTEST_HOME/build" "$GTEST_HOME/install"
rm -rf "$JSONCPP_HOME/build" "$JSONCPP_HOME/install"
rm -rf "$EFD_HOME/build"

mkdir -p "$GTEST_HOME/build" && cd "$GTEST_HOME/build"
git checkout -b "$GTEST_GIT_BRANCH" "$GTEST_GIT_BRANCH"
cmake ../                                           \
    -DCMAKE_INSTALL_PREFIX="$GTEST_HOME/install"    \
    -DCMAKE_BUILD_TYPE=Release                      \
    && make -j4 && make install

mkdir -p "$JSONCPP_HOME/build" && cd "$JSONCPP_HOME/build"
git checkout -b "$JSONCPP_GIT_BRANCH" "$JSONCPP_GIT_BRANCH"
cmake ../                                           \
    -DCMAKE_INSTALL_PREFIX="$JSONCPP_HOME/install"  \
    -DCMAKE_BUILD_TYPE=Release                      \
    && make -j4 && make install

mkdir -p "$EFD_HOME/build" && cd "$EFD_HOME/build"
cmake ../                                   \
    -DGTEST_ROOT=$GTEST_HOME/install        \
    -DJSONCPP_ROOT=$JSONCPP_HOME/install    \
    -DENABLE_TESTS=ON                       \
    -DCMAKE_BUILD_TYPE=Release              \
    && make -j4 && make test

if [ $? -eq 0 ]; then
    echo "Compilation Finished Successfully!"
else
    echo "Compilation Failed!"
fi
